{"vars":[{"kind":2,"line":2,"name":"StandardVersion","containerName":"Config::Model::Dpkg::Control::Source"},{"kind":12,"name":"extends","line":5},{"name":"Log4perl","line":7,"kind":2,"containerName":"Mouse::Log"},{"kind":2,"name":"feature","line":9,"containerName":""},{"kind":12,"name":"warnings","line":10},{"containerName":"","kind":2,"name":"Carp","line":14},{"kind":13,"line":14,"name":"$std_ver","containerName":null,"definition":"my","localvar":"my"},{"kind":13,"name":"$std_ver","line":15,"containerName":null},{"name":"croak","line":16,"kind":12},{"containerName":null,"kind":13,"name":"$std_ver","line":16},{"containerName":null,"localvar":"my","definition":"my","name":"$logger","line":18,"kind":13},{"kind":12,"line":18,"name":"get_logger"},{"kind":12,"line":20,"name":"_fetch_std","definition":"sub","containerName":"main::","range":{"start":{"line":20,"character":0},"end":{"character":9999,"line":22}},"children":[]},{"name":"_fetch_std_no_check","line":21,"kind":12},{"kind":12,"name":"_fetch_std_no_check","line":24,"definition":"sub","containerName":"main::","range":{"start":{"line":24,"character":0},"end":{"line":26,"character":9999}},"children":[{"containerName":"_fetch_std_no_check","kind":13,"name":"$std_ver","line":25}]},{"kind":12,"name":"compare_with_last_version","line":28,"signature":{"documentation":"","label":"compare_with_last_version($self,$to_check)","parameters":[{"label":"$self"},{"label":"$to_check"}]},"definition":"sub","detail":"($self,$to_check)","containerName":"main::","children":[{"kind":13,"line":29,"name":"$to_check","containerName":"compare_with_last_version"},{"containerName":"compare_with_last_version","kind":13,"line":32,"name":"$logger"},{"containerName":"compare_with_last_version","name":"warn","line":32,"kind":12},{"containerName":"compare_with_last_version","name":"$to_check","line":35,"kind":13},{"containerName":"compare_with_last_version","name":"$self","line":35,"kind":13},{"containerName":"compare_with_last_version","kind":12,"name":"_fetch_std_no_check","line":35}],"range":{"start":{"character":0,"line":28},"end":{"character":9999,"line":36}}},{"kind":12,"line":35,"name":"versioncmp"},{"kind":12,"name":"meta","line":38,"containerName":"main::"},{"kind":12,"line":38,"name":"make_immutable","containerName":"main::"}],"version":5}