{"version":5,"vars":[{"name":"warnings","line":5,"containerName":"","kind":2},{"name":"Log4perl","line":8,"containerName":"Log","kind":2},{"kind":12,"containerName":"Log4perl","line":9,"name":"Log"},{"name":"easy_init","line":9,"containerName":"main::","kind":12},{"kind":13,"line":9,"containerName":null,"name":"$WARN"},{"kind":12,"name":"with","line":13},{"kind":13,"localvar":"my","line":20,"definition":"my","containerName":null,"name":"$file"},{"kind":2,"line":20,"containerName":"Mouse::Path::Tiny::YAML","name":"PP"},{"kind":12,"name":"path","line":20},{"line":23,"kind":13,"localvar":"my","containerName":null,"definition":"my","name":"$parser"},{"kind":12,"name":"new","containerName":"main::","line":23},{"name":"$data","containerName":null,"definition":"my","line":27,"localvar":"my","kind":13},{"kind":13,"containerName":null,"line":27,"name":"$parser"},{"kind":12,"line":27,"containerName":"main::","name":"parse_dpkg_file"},{"kind":13,"name":"$file","containerName":null,"line":27},{"line":30,"name":"Dump","kind":12},{"containerName":null,"line":30,"name":"$data","kind":13}]}