{"vars":[{"name":"warnings","containerName":"","line":5,"kind":2},{"kind":2,"containerName":"Log","line":8,"name":"Log4perl"},{"line":9,"containerName":"Log4perl","name":"Log","kind":12},{"kind":12,"name":"easy_init","containerName":"main::","line":9},{"containerName":null,"line":9,"name":"$WARN","kind":13},{"line":13,"name":"with","kind":12},{"line":18,"localvar":"my","kind":13,"name":"$data","definition":"my","containerName":null},{"kind":2,"line":18,"containerName":"Mouse::Path","name":"Tiny"},{"kind":12,"name":"Files","line":25},{"line":26,"name":"Description","kind":12},{"name":"$parser","definition":"my","containerName":null,"localvar":"my","kind":13,"line":30},{"name":"new","containerName":"main::","line":30,"kind":12},{"kind":13,"containerName":null,"line":33,"name":"$parser"},{"name":"write_dpkg_file","containerName":"main::","line":33,"kind":12},{"containerName":null,"line":33,"name":"$data","kind":13}],"version":5}