{"vars":[{"containerName":null,"definition":"my","name":"@tests","kind":13,"localvar":"my","line":3},{"kind":2,"name":"warnings","line":3,"containerName":""},{"kind":12,"name":"name","line":5},{"kind":12,"line":7,"name":"load_check"},{"kind":12,"line":8,"name":"log4perl_load_warnings"},{"line":8,"name":"User","kind":12},{"line":8,"name":"warn","kind":12},{"line":9,"name":"check","kind":12},{"kind":12,"name":"load","line":12},{"line":15,"name":"load_check2","kind":12},{"line":20,"name":"conf_dir","kind":12},{"kind":12,"name":"tests","line":21},{"kind":13,"line":21,"containerName":null,"name":"@tests"}],"version":5}