{"version":5,"vars":[{"kind":2,"containerName":"","name":"feature","line":7},{"line":8,"name":"warnings","kind":12},{"line":10,"name":"JSON","containerName":"","kind":2},{"line":15,"definition":"sub","detail":"($self)","range":{"end":{"character":9999,"line":33},"start":{"line":15,"character":0}},"kind":12,"children":[{"containerName":"read_meta_data","localvar":"my","kind":13,"line":16,"name":"$root_path","definition":"my"},{"kind":13,"containerName":"read_meta_data","name":"$self","line":16},{"name":"instance","line":16,"kind":12,"containerName":"read_meta_data"},{"containerName":"read_meta_data","kind":12,"line":16,"name":"root_path"},{"localvar":"my","kind":13,"containerName":"read_meta_data","name":"$meta","definition":"my","line":17},{"definition":"my","name":"$ini","line":19,"localvar":"my","kind":13,"containerName":"read_meta_data"},{"name":"$root_path","line":19,"kind":13,"containerName":"read_meta_data"},{"kind":12,"containerName":"read_meta_data","name":"child","line":19},{"line":20,"name":"$meta_json","definition":"my","containerName":"read_meta_data","kind":13,"localvar":"my"},{"name":"$root_path","line":20,"kind":13,"containerName":"read_meta_data"},{"kind":12,"containerName":"read_meta_data","name":"child","line":20},{"kind":13,"containerName":"read_meta_data","name":"$ini","line":22},{"containerName":"read_meta_data","kind":12,"line":22,"name":"exists"},{"name":"$meta","line":23,"kind":13,"containerName":"read_meta_data"},{"kind":13,"containerName":"read_meta_data","name":"$self","line":23},{"name":"convert_ini","line":23,"kind":12,"containerName":"read_meta_data"},{"containerName":"read_meta_data","kind":13,"line":23,"name":"$ini"},{"line":25,"name":"$meta_json","containerName":"read_meta_data","kind":13},{"containerName":"read_meta_data","kind":12,"line":25,"name":"exists"},{"containerName":"read_meta_data","kind":13,"line":26,"name":"$meta"},{"containerName":"read_meta_data","kind":13,"line":26,"name":"$meta_json"},{"containerName":"read_meta_data","kind":12,"line":26,"name":"slurp_utf8"},{"kind":13,"containerName":"read_meta_data","name":"$meta","line":32}],"name":"read_meta_data","containerName":"main::","signature":{"label":"read_meta_data($self)","parameters":[{"label":"$self"}],"documentation":""}},{"containerName":"Config::INI::Reader::Debian::Upstream::Metadata","kind":2,"line":15,"name":"Perl"},{"line":26,"name":"decode_json","kind":12},{"kind":12,"name":"boil_down_meta","line":32},{"signature":{"label":"convert_ini( $self,$ini )","parameters":[{"label":" $self"},{"label":"$ini "}],"documentation":" convert dist.ini in a structure like the one returned by CPAN::Meta"},"containerName":"main::","name":"convert_ini","kind":12,"children":[{"containerName":"convert_ini","localvar":"my","kind":13,"line":37,"name":"$data","definition":"my"},{"line":37,"name":"read_file","containerName":"convert_ini","kind":12},{"containerName":"convert_ini","kind":13,"line":37,"name":"$ini"},{"name":"stringify","line":37,"kind":12,"containerName":"convert_ini"},{"line":40,"name":"$data","containerName":"convert_ini","kind":13},{"line":42,"name":"$data","containerName":"convert_ini","kind":13},{"kind":13,"containerName":"convert_ini","name":"$data","line":45}],"range":{"start":{"character":0,"line":36},"end":{"line":49,"character":9999}},"detail":"( $self,$ini )","definition":"sub","line":36},{"line":37,"name":"Config","containerName":"INI::Reader","kind":12},{"line":39,"name":"resources","kind":12},{"kind":12,"name":"homepage","line":40},{"kind":12,"line":40,"name":"MetaResources"},{"line":40,"name":"homepage","kind":12},{"line":41,"name":"repository","kind":12},{"line":42,"name":"url","kind":12},{"kind":12,"name":"MetaResources","line":42},{"name":"bugtracker","line":44,"kind":12},{"kind":12,"line":45,"name":"web"},{"kind":12,"name":"MetaResources","line":45}]}