{"vars":[{"line":7,"name":"feature","containerName":"","kind":2},{"line":8,"name":"warnings","kind":12},{"kind":12,"line":10,"name":"with"},{"line":12,"name":"base","containerName":"","kind":2},{"name":"update","signature":{"parameters":[{"label":" $self"},{"label":"%args "}],"label":"update( $self,%args )","documentation":""},"containerName":"main::","definition":"sub","line":19,"children":[{"line":20,"name":"$self","containerName":"update","kind":13},{"name":"$args","line":20,"kind":13,"containerName":"update"},{"containerName":"update","localvar":"my","kind":13,"line":24,"definition":"my","name":"$data"},{"kind":13,"containerName":"update","name":"$self","line":24},{"kind":12,"containerName":"update","name":"read_meta_data","line":24},{"kind":13,"localvar":"my","containerName":"update","name":"%mapping","definition":"my","line":27},{"kind":13,"localvar":"my","containerName":"update","definition":"my","name":"$from","line":34},{"line":34,"name":"%mapping","containerName":"update","kind":13},{"name":"$to","definition":"my","line":35,"localvar":"my","kind":13,"containerName":"update"},{"name":"$mapping","line":35,"kind":13,"containerName":"update"},{"name":"$from","line":35,"kind":13,"containerName":"update"},{"line":36,"name":"$self","containerName":"update","kind":13},{"kind":12,"containerName":"update","name":"fetch_element","line":36},{"name":"$to","line":36,"kind":13,"containerName":"update"},{"name":"store","line":36,"kind":12,"containerName":"update"},{"name":"$data","line":36,"kind":13,"containerName":"update"},{"line":36,"name":"$from","containerName":"update","kind":13}],"kind":12,"detail":"( $self,%args )","range":{"start":{"character":0,"line":19},"end":{"line":40,"character":9999}}},{"line":19,"name":"Perl","containerName":"Path::Tiny::CPAN::Meta::Config::INI::Reader::Debian::Upstream::Metadata","kind":2},{"name":"quiet","line":20,"kind":12},{"kind":12,"name":"quiet","line":20},{"kind":12,"line":31,"name":"Repository"}],"version":5}