{"vars":[{"name":"$conf_file_name","localvar":"my","kind":13,"line":3,"containerName":null,"definition":"my"},{"name":"warnings","line":3,"kind":2,"containerName":""},{"containerName":null,"line":5,"kind":13,"localvar":"my","name":"$conf_dir","definition":"my"},{"containerName":null,"kind":13,"localvar":"my","line":6,"name":"$model_to_test","definition":"my"},{"name":"@tests","kind":13,"localvar":"my","line":8,"containerName":null,"definition":"my"},{"name":"name","kind":12,"line":10},{"kind":12,"line":11,"name":"backend_arg"},{"line":11,"kind":13,"name":"$conf_file_name","containerName":null},{"kind":12,"line":12,"name":"check"},{"kind":12,"line":13,"name":"Documentation"},{"name":"name","line":17,"kind":12},{"line":18,"kind":12,"name":"backend_arg"},{"containerName":null,"kind":13,"line":18,"name":"$conf_file_name"},{"line":19,"kind":12,"name":"check"},{"line":24,"kind":12,"name":"name"},{"kind":12,"line":25,"name":"backend_arg"},{"line":25,"kind":13,"name":"$conf_file_name","containerName":null},{"name":"check","kind":12,"line":26},{"line":33,"kind":12,"name":"conf_file_name"},{"name":"$conf_file_name","line":33,"kind":13,"containerName":null},{"line":34,"kind":12,"name":"conf_dir"},{"line":34,"kind":13,"name":"$conf_dir","containerName":null},{"name":"tests","line":35,"kind":12},{"line":35,"kind":13,"name":"@tests","containerName":null}],"version":5}