{"version":5,"vars":[{"kind":2,"containerName":"","name":"feature","line":7},{"kind":12,"name":"warnings","line":8},{"name":"with","line":10,"kind":12},{"line":12,"name":"base","containerName":"","kind":2},{"name":"update","signature":{"documentation":"","label":"update($self,%args)","parameters":[{"label":"$self"},{"label":"%args"}]},"containerName":"main::","definition":"sub","line":19,"children":[{"containerName":"update","kind":13,"line":20,"name":"$self"},{"containerName":"update","kind":13,"line":20,"name":"$args"},{"line":22,"definition":"my","name":"$data","containerName":"update","kind":13,"localvar":"my"},{"kind":13,"containerName":"update","name":"$self","line":22},{"line":22,"name":"read_meta_data","containerName":"update","kind":12},{"kind":13,"containerName":"update","name":"$self","line":24},{"kind":12,"containerName":"update","name":"load_data","line":24},{"kind":13,"containerName":"update","name":"$data","line":24}],"kind":12,"range":{"end":{"character":9999,"line":27},"start":{"line":19,"character":0}},"detail":"($self,%args)"},{"containerName":"Path::Tiny::CPAN::Meta::Config::INI::Reader::Debian::Upstream::Metadata","kind":2,"line":19,"name":"Perl"},{"kind":12,"name":"quiet","line":20},{"line":20,"name":"quiet","kind":12}]}