{"vars":[{"line":2,"containerName":"Dpkg::Copyright::Grant::ByFile","name":"MostRecentEmail","kind":2},{"line":9,"containerName":"","name":"feature","kind":2},{"kind":12,"line":10,"name":"warnings"},{"line":12,"name":"email","kind":12},{"kind":12,"name":"is","line":13},{"kind":12,"name":"isa","line":14},{"kind":12,"line":15,"name":"default"},{"kind":12,"line":18,"name":"year"},{"kind":12,"name":"is","line":19},{"kind":12,"name":"isa","line":20},{"name":"default","line":21,"kind":12},{"detail":"($self,$st)","name":"update_email_if_more_recent","signature":{"label":"update_email_if_more_recent($self,$st)","parameters":[{"label":"$self"},{"label":"$st"}],"documentation":""},"range":{"end":{"line":32,"character":9999},"start":{"line":24,"character":0}},"containerName":"main::","children":[{"localvar":"my","kind":13,"line":25,"name":"$year","definition":"my","containerName":"update_email_if_more_recent"},{"name":"$st","line":25,"containerName":"update_email_if_more_recent","kind":13},{"kind":12,"name":"range","containerName":"update_email_if_more_recent","line":25},{"containerName":"update_email_if_more_recent","line":27,"name":"$st","kind":13},{"containerName":"update_email_if_more_recent","line":27,"name":"email","kind":12},{"line":28,"containerName":"update_email_if_more_recent","name":"$self","kind":13},{"kind":12,"containerName":"update_email_if_more_recent","line":28,"name":"email"},{"line":28,"containerName":"update_email_if_more_recent","name":"$year","kind":13},{"name":"$self","containerName":"update_email_if_more_recent","line":28,"kind":13},{"containerName":"update_email_if_more_recent","line":28,"name":"year","kind":12},{"kind":13,"containerName":"update_email_if_more_recent","line":30,"name":"$self"},{"containerName":"update_email_if_more_recent","line":30,"name":"email","kind":12},{"name":"$st","containerName":"update_email_if_more_recent","line":30,"kind":13},{"line":30,"containerName":"update_email_if_more_recent","name":"email","kind":12},{"name":"$self","line":31,"containerName":"update_email_if_more_recent","kind":13},{"containerName":"update_email_if_more_recent","line":31,"name":"year","kind":12},{"containerName":"update_email_if_more_recent","line":31,"name":"$year","kind":13}],"definition":"sub","kind":12,"line":24}],"version":5}