{"vars":[{"line":3,"kind":13,"localvar":"my","definition":"my","containerName":null,"name":"$conf_file_name"},{"name":"warnings","line":3,"containerName":"","kind":2},{"definition":"my","containerName":null,"name":"$conf_dir","line":5,"kind":13,"localvar":"my"},{"line":6,"localvar":"my","kind":13,"name":"$model_to_test","containerName":null,"definition":"my"},{"line":8,"localvar":"my","kind":13,"name":"@tests","containerName":null,"definition":"my"},{"kind":12,"line":10,"name":"name"},{"kind":12,"line":11,"name":"backend_arg"},{"containerName":null,"line":11,"name":"$conf_file_name","kind":13},{"kind":12,"line":12,"name":"log4perl_load_warnings"},{"name":"warn","line":14,"kind":12},{"kind":12,"name":"warn","line":15},{"name":"warn","line":16,"kind":12},{"name":"warn","line":17,"kind":12},{"line":18,"name":"warn","kind":12},{"line":19,"name":"warn","kind":12},{"line":20,"name":"warn","kind":12},{"line":22,"name":"load","kind":12},{"name":"apply_fix","line":23,"kind":12},{"name":"check","line":24,"kind":12},{"kind":12,"name":"name","line":36},{"kind":12,"name":"backend_arg","line":37},{"containerName":null,"line":37,"name":"$conf_file_name","kind":13},{"line":38,"name":"check","kind":12},{"kind":12,"line":42,"name":"file_contents_like"},{"line":47,"name":"name","kind":12},{"kind":12,"line":48,"name":"backend_arg"},{"name":"$conf_file_name","line":48,"containerName":null,"kind":13},{"kind":12,"line":49,"name":"check"},{"line":50,"name":"Synopsis","kind":12},{"kind":12,"name":"Description","line":51},{"kind":12,"line":52,"name":"diff"},{"kind":12,"name":"apply_fix","line":54},{"name":"file_contents_like","line":56,"kind":12},{"line":62,"name":"name","kind":12},{"line":63,"name":"backend_arg","kind":12},{"name":"$conf_file_name","containerName":null,"line":63,"kind":13},{"line":64,"name":"log4perl_load_warnings","kind":12},{"kind":12,"line":66,"name":"apply_fix"},{"kind":12,"line":67,"name":"check"},{"kind":12,"line":68,"name":"Synopsis"},{"line":72,"name":"name","kind":12},{"name":"backend_arg","line":73,"kind":12},{"kind":13,"name":"$conf_file_name","line":73,"containerName":null},{"name":"check","line":74,"kind":12},{"name":"Subject","line":76,"kind":12},{"line":80,"name":"name","kind":12},{"name":"backend_arg","line":81,"kind":12},{"name":"$conf_file_name","containerName":null,"line":81,"kind":13},{"kind":12,"name":"check","line":82},{"line":84,"name":"Subject","kind":12},{"kind":12,"line":85,"name":"Description"},{"kind":12,"name":"name","line":89},{"kind":12,"line":90,"name":"backend_arg"},{"kind":13,"name":"$conf_file_name","line":90,"containerName":null},{"name":"check","line":91,"kind":12},{"line":93,"name":"Subject","kind":12},{"name":"Description","line":94,"kind":12},{"line":98,"name":"name","kind":12},{"kind":12,"line":99,"name":"backend_arg"},{"kind":13,"name":"$conf_file_name","line":99,"containerName":null},{"kind":12,"name":"check","line":100},{"name":"Subject","line":102,"kind":12},{"name":"Description","line":103,"kind":12},{"kind":12,"line":109,"name":"conf_file_name"},{"kind":13,"line":109,"containerName":null,"name":"$conf_file_name"},{"kind":12,"line":110,"name":"conf_dir"},{"kind":13,"name":"$conf_dir","line":110,"containerName":null},{"kind":12,"name":"tests","line":111},{"kind":13,"name":"@tests","containerName":null,"line":111}],"version":5}